function x = radial_average_2d(x)
    %Apply angular average to the 2D image.
    %
    % X = RADIAL_AVERAGE_2d(X) Calculate circularly symmetric image
    % by averaging intensity along the angular dimension. The center 
    % of rotation conincides with the center of the image. 
    %
    % See Also: radial_average, rrr

    % Image size:
    sz = size(x);
    
    % Coordinates:
    rs = rrr(sz);

    % Loop in the radial direction:
    for ii = 0:(sz(1) / 2 * sqrt(2))
        index = (rs >= ii) & (rs < (ii+1));
        x(index) = mean(x(index));
    end
end
