function show(a, lims, fig, title_text)
%Display an image. 
% SHOW is intended for showing 1D, 2D and 3D data, 
% including gpuArray objects.
% Depending on the type of the first parameter it calls one of
% the following functions:
%   imshow()
%   dipshow()
%   plot()
% SHOW(A, LIMS, FIG, TITLE_TEXT) will display A using grayscale
% limits LIMS, figure number FIG, and title TITLE_TEXT.
% Example: show(a, [], 1, 'Erika');

if isa(a, 'parallel.gpu.GPUArray')
    a = gather(a);
end

% Use plot for 1D data:
if length(a) == numel(a)
    if nargin == 3
        figure(fig);
    end
    
    if nargin < 2
        plot(a);
    else
        plot(a, lims);
    end
    
% Use dipshow for dip_image or 3D:
elseif isa(a, 'dip_image') | strcmp(lims, 'percentile') | strcmp(lims, 'lin') | size(a, 3) > 1
    if nargin < 3
        dipshow(a, lims);
    else
        dipshow(fig, a, lims);
    end
else
    
    % Use imshow for matlab 2D images:
    if nargin < 3
        figure;
    else
        if ~isempty(fig)          
            figure(fig);
        end
    end
    
    imshow(a, lims);
end

% Add title:
if nargin > 3
    title(title_text);
end

end