classdef CPU_mat3df < CPU_mat3d
    %CPU_MAT Math routines realized on CPU.
    %
    % Math routines used in TV-minimization. Class is fully static
    % and does not have to be initialized.
    % 
    % Example 1 (static use): 
    %
    % image_norm = CPU_mat.norm(image);
    %
    % Example 2 (instantiated use):   
    %
    % m = CPU_mat;
    % image_norm = m.norm(image);
    %
    % See also: GPU_mat
    
    methods(Static)
        
       function x = dx(x)
            % Horizontal derivative of x

            %x(1:end - 1, :, :) = x(1:end - 1, :, :) - x(2:end, :, :);
            %x(end, :, :) = 0;
            
            % faster:
            x(1:end - 1, :, :) = -diff(x, [], 1);
        end

        function x = dy(x)
            % Vertical derivative of x

            %x(:, 1:end - 1, :) = x(:, 1:end - 1, :) - x(:, 2:end, :);
            %x(:, end, :) = 0;
            
            % faster:
            x(:, 1:end - 1, :) = -diff(x, [], 2);
        end
        
        function x = dz(x)
            % Vertical derivative of z

            %x(:, :, 1:end - 1) = x(:, :, 1:end - 1) - x(:, :, 2:end);
            %x(:, :, end) = 0;
            
            % faster:
            x(:, :, 1:end - 1) = -diff(x, [], 3);
        end

        function x = dx_(x)
            % Horizontal(transposed) derivative of x

            x(2:end, :, :) = -diff(x, [], 1);
        end

        function x = dy_(x)
            % Vertical(transposed) derivative of x

            x(:, 2:end, :) = -diff(x, [], 2);
        end

        function x = dz_(x)
            % Vertical(transposed) derivative of z

            x(:, :, 2:end) = -diff(x, [], 3);
        end
        
    end
end
