classdef unit_convert
% This class provides physical constants and converts units. Doesn't have
% to be initialized (Static class).
    
    properties(Constant=true)
		c = 299792458; %m/s
		
		h = 6.62606896e-34; % J*S
		h_ev = 4.13566733e-15;%eV*s
		h_bar = 1.054571628e-34; %J*s
		h_bar_ev = 6.58211899e-16; %eV*s
        e = 1.602176565e-19; % coulomb

		Na = 6.02214179e23; % mol-1
		re = 2.817940289458e-15; % m

		me = 9.10938215e-31; % kg
		me_ev = 0.510998910e6; % ev/c^2 
    end
      
    methods(Static)
        
        function lambda = k2lambda(k)
            lambda = 2*pi ./ k;
        end
        
        function k = lambda2k(lambda)
            k = 2*pi ./ lambda;
        end
        
        function lambda = e2lambda(e) % m
            lambda = 2*pi*(unit_convert.h_bar_ev * unit_convert.c)./e;
        end
        
        function e = lambda2e(lambda) % eV
            e = 2*pi*(unit_convert.h_bar_ev * unit_convert.c)./lambda;
        end

        function k = e2k(e) % m
            k = e /(unit_convert.h_bar_ev * unit_convert.c);
        end
        
        function e = k2e(k) % eV
            e = (unit_convert.h_bar_ev * unit_convert.c).*k;
        end
	end
end
