%This script shows how to use TV-minimization for debluring. 
%
% Same as <a href="matlab:help debluring_example">debluring_example</a> but using GPU computations.

% Original image:
image = gpuArray(chimp());

% Gaussian PSF:
sigma = 2;
center = size(image)/2 + 1;

PSF = (1 / (2 * pi * sigma^2)) * ...
exp(-((xxx(image, center)/sigma).^2 + ...
(yyy(image, center)/sigma).^2) / 2);

% Make all inputs gpuArray:
PSF = gpuArray(ifftshift(PSF));

CTF = fft2(PSF);

% Generate blurred image:
photo = real(ifft2( fft2(image) .* CTF ));

% Add Gaussian noise:
photo = photo + 1 * (randn(size(photo)));

% Display:
show(photo, [], 1); title('Blured');

% Initialize the TV_min:
f = TV_min();

% Replace CPU calculator with the GPU version
f.calc = GPU_mat;

% Define the linear model A(x):
f.A = @(x) CTF .* fft2(x);
f.A_trans = @(x) real(ifft2( conj(CTF) .* x ));

% Define x and y in A(x) = y:
f.X = zeros(size(photo));
f.Y = fft2(photo);
 
% Calculate the Lipschitz constant L = 2*max(|A|.^2):
f.L = 2*f.calc.max(CTF.^2);
 
% Initialization parameters of the algorithm:
f.n_iter = 100;
f.lambda = 0.5;
f.bounds = [-inf, inf];
f.X_true = image;
 
% Calculate!
[x, history] = f.run();
 
% Show the result:
show(x, [],2 , 'TV min');

% Display the history of convergence:
figure(3); 
semilogy(history.L2 + history.TV); title('Cost function');

figure(4); 
semilogy(history.err); title('Error');

