%This script shows how to use TV-minimization for tomographic reconstruction. 
%
% First the sinogram of the standard head phantom is generated,
% Gaussian noise applied. Then TV-minimization routines are 
% initialized by creating a TV_min object and defining some 
% of it's basic properties. At last solution is obtained by
% running iterative minimization implemented in TV_min.

% Tomographic data simulation:
theta = 1:5:180;
 
vol = phantom(256);
sino = radon(vol, theta);
 
% Display the phantom and the FBP reconstruction:
figure(1); 
imshow(vol, []); title('Phantom'); 

figure(2); 
imshow(iradon(sino, theta, 'linear', 'Ram-Lak', 1, 256), []); title('FBP'); 

% Initialize the TV_min:
f = TV_min();
 
% Define the linear model A(x):
f.A = @(x) radon(x, theta);
f.A_trans = @(x) iradon(x, theta, 'linear', 'none', 1, 256);

% Define x and y in A(x) = y:
f.X = zeros(size(vol));
f.Y = sino;
 
% Calculate the Lipschitz constant L = 2*max(|A|.^2):
f.L = 2*max(max(f.A_trans(f.A( ones(size(vol) )))));
 
% Initialization parameters of the algorithm:
f.n_iter = 200;
f.lambda = 1;
f.bounds = [0, inf];
f.X_true = vol;
 
% Calculate!
[x, history] = f.run();

show(x, [], 3, 'TV min');

% Display the history of convergence:
figure(4); 
semilogy(history.L2 + history.TV); title('Cost function');

figure(5); 
semilogy(history.err); title('Error');
