%This script shows how to use TV-minimization for tomographic reconstruction. 
%
% Same as <a href="matlab:help tomography_example">tomography_example</a> but using GPU computations.

% Tomographic data simulation:
theta = 1:5:180;
 
% Initialize GPU_mat to use GPU computations:
gpuCalc = GPU_mat;

% Generate data:
vol = gpuArray(single(phantom(256)));
sino = gpuCalc.RADON(vol, theta);
 
% Display the phantom and the FBP reconstruction:
show(vol, [], 1); title('Phantom'); 

% Initialize the TV_min:
f = TV_min();

% Replace CPU calculator with the GPU version
f.calc = gpuCalc;
 
% Define the linear model A(x):
f.A = @(x) gpuCalc.RADON(x, theta);
f.A_trans = @(x) gpuCalc.IRADON(x, theta);

% Define x and y in A(x) = y:
f.X = gpuCalc.gpu_array(size(vol));
f.Y = sino;
 
% Calculate the Lipschitz constant L = 2*max(|A|.^2):
f.L = 2*gpuCalc.max(f.A_trans(f.A( ones(size(vol) ))));
 
% Initialization parameters of the algorithm:
f.n_iter = 200;
f.lambda = 1;
f.bounds = [0, inf];
f.X_true = vol;
 
% Calculate!
[x, history] = f.run();
 
% Display the history of convergence:
figure(3); 
semilogy(history.L2 + history.TV); title('Cost function');

figure(4); 
semilogy(history.err); title('Error');
